@@ -1,221 +1,13 @@
 package Module::AutoInstall;
-$Module::AutoInstall::VERSION = '1.01';
 
 use strict;
 use Cwd                 ();
 use ExtUtils::MakeMaker ();
 
-=head1 NAME
-
-Module::AutoInstall - Automatic install of dependencies via CPAN
-
-=head1 SYNOPSIS
-
-In F<Makefile.PL>, with L<Module::Install> available on the author's system:
-
-    use inc::Module::Install;
-    
-    name        'Joe-Hacker';
-    abstract    'Perl Interface to Joe Hacker';
-    author      'Joe Hacker <joe@hacker.org>';
-    include     'Module::AutoInstall';
-    
-    requires    'Module0';          # mandatory modules
-    
-    feature     'Feature1',
-        -default    => 0,
-        'Module2'   => '0.1';
-    
-    feature     'Feature2',
-        -default    => 0,
-        'Module3'   => '1.0';
-    
-    auto_install(
-        make_args   => '--hello',   # option(s) for CPAN::Config
-        force       => 1,           # pseudo-option to force install
-        do_once     => 1,           # skip previously failed modules
-    );
-    
-    WriteAll;
-
-Invoking the resulting F<Makefile.PL>:
-
-    % perl Makefile.PL                  # interactive behaviour
-    % perl Makefile.PL --defaultdeps    # accept default value on prompts
-    % perl Makefile.PL --checkdeps      # check only, no Makefile produced
-    % perl Makefile.PL --skipdeps       # ignores all dependencies
-    % perl Makefile.PL --testonly       # don't write installation targets
-
-Note that the trailing 'deps' of arguments may be omitted, too.
-
-Using C<--defaultdeps> will make F<Makefile.PL> behave similarly to a regular
-Makefile.PL file with C<PREREQ_PM> dependencies.
-
-One can use environment variables (see "ENVIRONMENT") below to set a default
-behavior instead of specifying it in the command line for every invocation
-of F<Makefile.PL>.
-
-Using F<make> (or F<nmake>):
-
-    % make [all|test|install]           # install dependencies first
-    % make checkdeps                    # same as the --checkdeps above
-    % make installdeps                  # install dependencies only
-
-=head1 DESCRIPTION
-
-B<Module::AutoInstall> lets module writers to specify a more
-sophisticated form of dependency information than the C<PREREQ_PM>
-option offered by B<ExtUtils::MakeMaker>.
-
-This module works best with the B<Module::Install> framework,
-a drop-in replacement for MakeMaker.  However, this module also
-supports F<Makefile.PL> files based on MakeMaker; see L</EXAMPLES>
-for instructions.
-
-=head2 Prerequisites and Features
-
-Prerequisites are grouped into B<features>, and the user could choose
-yes/no on each one's dependencies; the module writer may also supply a
-boolean value via C<-default> to specify the default choice.
-
-The B<Core Features> marked by the name C<-core> will double-check with
-the user, if the user chooses not to install the mandatory modules.
-This differs from the pre-0.26 'silent install' behaviour.
-
-Starting from version 0.27, if C<-core> is set to the string C<all>
-(case-insensitive), every feature will be considered mandatory.
-
-The dependencies are expressed as pairs of C<Module> => C<version>
-inside an array reference.  If the order does not matter, and there
-are no C<-default>, C<-tests> or C<-skiptests> directives for that
-feature, you may also use a hash reference.
-
-=head2 The Installation Process
-
-Once B<Module::AutoInstall> has determined which module(s) are needed,
-it checks whether it's running under the B<CPAN> shell and should
-therefore let B<CPAN> handle the dependency.
-
-Finally, the C<WriteMakefile()> is overridden to perform some additional
-checks, as well as skips tests associated with disabled features by the
-C<-tests> option.
-
-The actual installation happens at the end of the C<make config> target;
-both C<make test> and C<make install> will trigger the installation of
-required modules.
-
-If it's not running under B<CPAN>, the installer will probe for an
-active connection by trying to resolve the domain C<cpan.org>, and check
-for the user's permission to use B<CPAN>.  If all went well, a separate
-    B<CPAN> instance is created to install the required modules.
-
-If you have the B<CPANPLUS> package installed in your system, it is
-preferred by default over B<CPAN>; it also accepts some extra options
-(e.g. C<-target =E<gt> 'skiptest', -skiptest =E<gt> 1> to skip testing).
-
-All modules scheduled to be installed will be deleted from C<%INC>
-first, so B<ExtUtils::MakeMaker> will check the newly installed modules.
-
-Additionally, you could use the C<make installdeps> target to install
-the modules, and the C<make checkdeps> target to check dependencies
-without actually installing them; the C<perl Makefile.PL --checkdeps>
-command has an equivalent effect.
-
-If the F<Makefile.PL> itself needs to use an independent module (e.g.
-B<Acme::KillarApp>, v1.21 or greater), then use something like below:
-
-    BEGIN {
-        require Module::AutoInstall;
-        # the first argument is an arrayref of the -config flags
-        Module::AutoInstall->install([], 'Acme::KillerApp' => 1.21);
-    }
-    use Acme::KillerApp 1.21;
-
-    Module::AutoInstall->import(
-        # ... arguments as usual ...
-    );
-
-Note the version test in the use clause; if you are so close to the
-cutting edge that B<Acme::KillerApp> 1.20 is the latest version on CPAN,
-this will prevent your module from going awry.
-
-=head2 User-Defined Hooks
-
-User-defined I<pre-installation> and I<post-installation> hooks are
-available via C<MY::preinstall> and C<MY::postinstall> subroutines,
-as shown below:
-
-    # pre-install handler; takes $module_name and $version
-    sub MY::preinstall  { return 1; } # return false to skip install
-
-    # post-install handler; takes $module_name, $version, $success
-    sub MY::postinstall { return; }   # the return value doesn't matter
-
-Note that since B<Module::AutoInstall> performs installation at the
-time of C<use> (i.e. before perl parses the remainder of
-F<Makefile.PL>), you have to declare those two handlers I<before> the
-C<use> statement for them to take effect.
-
-If the user did not choose to install a module or it already exists on
-the system, neither of the handlers is invoked.  Both handlers are invoked
-exactly once for each module when installation is attempted.
-
-C<MY::preinstall> takes two arguments, C<$module_name> and C<$version>;
-if it returns a false value, installation for that module will be
-skipped, and C<MY::postinstall> won't be called at all.
-
-C<MY::postinstall> takes three arguments, C<$module_name>, C<$version>
-and C<$success>.  The last one denotes whether the installation
-succeeded or not: C<1> means installation completed successfully, C<0>
-means failure during install, and C<undef> means that the installation
-was not attempted at all, possibly due to connection problems, or that
-module does not exist on CPAN at all.
-
-=head2 Customized C<MY::postamble>
-
-Starting from version 0.43, B<Module::AutoInstall> supports modules
-that require a C<MY::postamble> subroutine in their F<Makefile.PL>.
-The user-defined C<MY::postamble>, if present, is responsible for
-calling C<Module::AutoInstall::postamble> and include the output in
-its return value.
-
-For example, the B<DBD::*> (database driver) modules for the Perl DBI
-are required to include the postamble generated by the function
-C<dbd_postamble>, so their F<Makefile.PL> may contain lines like this:
-
-    sub MY::postamble {
-        return &Module::AutoInstall::postamble . &dbd_postamble;
-    }
-
-Note that the B<Module::AutoInstall> module does not export the
-C<postamble> function, so the name should always be fully qualified.
-
-=head1 CAVEATS
-
-B<Module::AutoInstall> will add C<UNINST=1> to your B<make install>
-flags if your effective uid is 0 (root), unless you explicitly disable
-it by setting B<CPAN>'s C<make_install_arg> configuration option (or the
-C<makeflags> option of B<CPANPLUS>) to include C<UNINST=0>.  This I<may>
-cause dependency problems if you are using a fine-tuned directory
-structure for your site.  Please consult L<CPAN/FAQ> for an explanation
-in detail.
-
-If either B<version> or B<Sort::Versions> is available, they will be
-used to compare the required version with the existing module's version
-and the CPAN module's.  Otherwise it silently falls back to use I<cmp>.
-This may cause inconsistent behaviours in pathetic situations.
-
-=head1 ENVIRONMENT
-
-B<Module::AutoInstall> uses a single environment variable,
-C<PERL_AUTOINSTALL>.  It is taken as the command line argument
-passed to F<Makefile.PL>; you could set it to either C<--defaultdeps> or
-C<--skipdeps> to avoid interactive behaviour.
-
-It also read from the C<PERL_EXTUTILS_AUTOINSTALL> environment variable if
-C<PERL_AUTOINSTALL> is not defined.
-
-=cut
+use vars qw{$VERSION};
+BEGIN {
+	$VERSION = '1.02';
+}
 
 # special map on pre-defined feature sets
 my %FeatureMap = (
@@ -228,7 +20,8 @@ my ( @Missing, @Existing,  %DisabledTests, $UnderCPAN,     $HasCPANPLUS );
 my ( $Config,  $CheckOnly, $SkipInstall,   $AcceptDefault, $TestOnly );
 my ( $PostambleActions, $PostambleUsed );
 
-_accept_default( !-t STDIN );      # see if it's a non-interactive session
+# See if it's a testing or non-interactive session
+_accept_default( $ENV{AUTOMATED_TESTING} or ! -t STDIN ); 
 _init();
 
 sub _accept_default {
@@ -301,7 +94,7 @@ sub import {
     my $core_all;
 
     print "*** $class version " . $class->VERSION . "\n";
-    print "*** Checking for dependencies...\n";
+    print "*** Checking for Perl dependencies...\n";
 
     my $cwd = Cwd::cwd();
 
@@ -899,7 +692,7 @@ sub _make_args {
     $PostambleActions = (
         $missing
         ? "\$(PERL) $0 --config=$config --installdeps=$missing"
-        : "\@\$(NOOP)"
+        : "\$(NOECHO) \$(NOOP)"
     );
 
     return %args;
@@ -940,7 +733,7 @@ sub postamble {
     return << ".";
 
 config :: installdeps
-\t\@\$(NOOP)
+\t\$(NOECHO) \$(NOOP)
 
 checkdeps ::
 \t\$(PERL) $0 --checkdeps
@@ -956,6 +749,218 @@ installdeps ::
 
 __END__
 
+=pod
+
+=head1 NAME
+
+Module::AutoInstall - Automatic install of dependencies via CPAN
+
+=head1 SYNOPSIS
+
+In F<Makefile.PL>, with L<Module::Install> available on the author's system:
+
+    use inc::Module::Install;
+    
+    name        'Joe-Hacker';
+    abstract    'Perl Interface to Joe Hacker';
+    author      'Joe Hacker <joe@hacker.org>';
+    include     'Module::AutoInstall';
+    
+    requires    'Module0';          # mandatory modules
+    
+    feature     'Feature1',
+        -default    => 0,
+        'Module2'   => '0.1';
+    
+    feature     'Feature2',
+        -default    => 0,
+        'Module3'   => '1.0';
+    
+    auto_install(
+        make_args   => '--hello',   # option(s) for CPAN::Config
+        force       => 1,           # pseudo-option to force install
+        do_once     => 1,           # skip previously failed modules
+    );
+    
+    WriteAll;
+
+Invoking the resulting F<Makefile.PL>:
+
+    % perl Makefile.PL                  # interactive behaviour
+    % perl Makefile.PL --defaultdeps    # accept default value on prompts
+    % perl Makefile.PL --checkdeps      # check only, no Makefile produced
+    % perl Makefile.PL --skipdeps       # ignores all dependencies
+    % perl Makefile.PL --testonly       # don't write installation targets
+
+Note that the trailing 'deps' of arguments may be omitted, too.
+
+Using C<--defaultdeps> will make F<Makefile.PL> behave similarly to a regular
+Makefile.PL file with C<PREREQ_PM> dependencies.
+
+One can use environment variables (see "ENVIRONMENT") below to set a default
+behavior instead of specifying it in the command line for every invocation
+of F<Makefile.PL>.
+
+Using F<make> (or F<nmake>):
+
+    % make [all|test|install]           # install dependencies first
+    % make checkdeps                    # same as the --checkdeps above
+    % make installdeps                  # install dependencies only
+
+=head1 DESCRIPTION
+
+B<Module::AutoInstall> lets module writers to specify a more
+sophisticated form of dependency information than the C<PREREQ_PM>
+option offered by B<ExtUtils::MakeMaker>.
+
+This module works best with the B<Module::Install> framework,
+a drop-in replacement for MakeMaker.  However, this module also
+supports F<Makefile.PL> files based on MakeMaker; see L</EXAMPLES>
+for instructions.
+
+=head2 Prerequisites and Features
+
+Prerequisites are grouped into B<features>, and the user could choose
+yes/no on each one's dependencies; the module writer may also supply a
+boolean value via C<-default> to specify the default choice.
+
+The B<Core Features> marked by the name C<-core> will double-check with
+the user, if the user chooses not to install the mandatory modules.
+This differs from the pre-0.26 'silent install' behaviour.
+
+Starting from version 0.27, if C<-core> is set to the string C<all>
+(case-insensitive), every feature will be considered mandatory.
+
+The dependencies are expressed as pairs of C<Module> => C<version>
+inside an array reference.  If the order does not matter, and there
+are no C<-default>, C<-tests> or C<-skiptests> directives for that
+feature, you may also use a hash reference.
+
+=head2 The Installation Process
+
+Once B<Module::AutoInstall> has determined which module(s) are needed,
+it checks whether it's running under the B<CPAN> shell and should
+therefore let B<CPAN> handle the dependency.
+
+Finally, the C<WriteMakefile()> is overridden to perform some additional
+checks, as well as skips tests associated with disabled features by the
+C<-tests> option.
+
+The actual installation happens at the end of the C<make config> target;
+both C<make test> and C<make install> will trigger the installation of
+required modules.
+
+If it's not running under B<CPAN>, the installer will probe for an
+active connection by trying to resolve the domain C<cpan.org>, and check
+for the user's permission to use B<CPAN>.  If all went well, a separate
+    B<CPAN> instance is created to install the required modules.
+
+If you have the B<CPANPLUS> package installed in your system, it is
+preferred by default over B<CPAN>; it also accepts some extra options
+(e.g. C<-target =E<gt> 'skiptest', -skiptest =E<gt> 1> to skip testing).
+
+All modules scheduled to be installed will be deleted from C<%INC>
+first, so B<ExtUtils::MakeMaker> will check the newly installed modules.
+
+Additionally, you could use the C<make installdeps> target to install
+the modules, and the C<make checkdeps> target to check dependencies
+without actually installing them; the C<perl Makefile.PL --checkdeps>
+command has an equivalent effect.
+
+If the F<Makefile.PL> itself needs to use an independent module (e.g.
+B<Acme::KillarApp>, v1.21 or greater), then use something like below:
+
+    BEGIN {
+        require Module::AutoInstall;
+        # the first argument is an arrayref of the -config flags
+        Module::AutoInstall->install([], 'Acme::KillerApp' => 1.21);
+    }
+    use Acme::KillerApp 1.21;
+
+    Module::AutoInstall->import(
+        # ... arguments as usual ...
+    );
+
+Note the version test in the use clause; if you are so close to the
+cutting edge that B<Acme::KillerApp> 1.20 is the latest version on CPAN,
+this will prevent your module from going awry.
+
+=head2 User-Defined Hooks
+
+User-defined I<pre-installation> and I<post-installation> hooks are
+available via C<MY::preinstall> and C<MY::postinstall> subroutines,
+as shown below:
+
+    # pre-install handler; takes $module_name and $version
+    sub MY::preinstall  { return 1; } # return false to skip install
+
+    # post-install handler; takes $module_name, $version, $success
+    sub MY::postinstall { return; }   # the return value doesn't matter
+
+Note that since B<Module::AutoInstall> performs installation at the
+time of C<use> (i.e. before perl parses the remainder of
+F<Makefile.PL>), you have to declare those two handlers I<before> the
+C<use> statement for them to take effect.
+
+If the user did not choose to install a module or it already exists on
+the system, neither of the handlers is invoked.  Both handlers are invoked
+exactly once for each module when installation is attempted.
+
+C<MY::preinstall> takes two arguments, C<$module_name> and C<$version>;
+if it returns a false value, installation for that module will be
+skipped, and C<MY::postinstall> won't be called at all.
+
+C<MY::postinstall> takes three arguments, C<$module_name>, C<$version>
+and C<$success>.  The last one denotes whether the installation
+succeeded or not: C<1> means installation completed successfully, C<0>
+means failure during install, and C<undef> means that the installation
+was not attempted at all, possibly due to connection problems, or that
+module does not exist on CPAN at all.
+
+=head2 Customized C<MY::postamble>
+
+Starting from version 0.43, B<Module::AutoInstall> supports modules
+that require a C<MY::postamble> subroutine in their F<Makefile.PL>.
+The user-defined C<MY::postamble>, if present, is responsible for
+calling C<Module::AutoInstall::postamble> and include the output in
+its return value.
+
+For example, the B<DBD::*> (database driver) modules for the Perl DBI
+are required to include the postamble generated by the function
+C<dbd_postamble>, so their F<Makefile.PL> may contain lines like this:
+
+    sub MY::postamble {
+        return &Module::AutoInstall::postamble . &dbd_postamble;
+    }
+
+Note that the B<Module::AutoInstall> module does not export the
+C<postamble> function, so the name should always be fully qualified.
+
+=head1 CAVEATS
+
+B<Module::AutoInstall> will add C<UNINST=1> to your B<make install>
+flags if your effective uid is 0 (root), unless you explicitly disable
+it by setting B<CPAN>'s C<make_install_arg> configuration option (or the
+C<makeflags> option of B<CPANPLUS>) to include C<UNINST=0>.  This I<may>
+cause dependency problems if you are using a fine-tuned directory
+structure for your site.  Please consult L<CPAN/FAQ> for an explanation
+in detail.
+
+If either B<version> or B<Sort::Versions> is available, they will be
+used to compare the required version with the existing module's version
+and the CPAN module's.  Otherwise it silently falls back to use I<cmp>.
+This may cause inconsistent behaviours in pathetic situations.
+
+=head1 ENVIRONMENT
+
+B<Module::AutoInstall> uses a single environment variable,
+C<PERL_AUTOINSTALL>.  It is taken as the command line argument
+passed to F<Makefile.PL>; you could set it to either C<--defaultdeps> or
+C<--skipdeps> to avoid interactive behaviour.
+
+It also read from the C<PERL_EXTUTILS_AUTOINSTALL> environment variable if
+C<PERL_AUTOINSTALL> is not defined.
+
 =head1 SEE ALSO
 
 L<Module::Install>
@@ -967,9 +972,13 @@ L<CPANPLUS>
 
 Audrey Tang E<lt>autrijus@autrijus.orgE<gt>
 
+Adam Kennedy E<lt>cpan@ali.asE<gt>
+
 =head1 COPYRIGHT
 
-Copyright 2001, 2002, 2003, 2004, 2005, 2006 by Audrey Tang.
+Copyright 2001, 2002, 2003, 2004, 2005, 2006 by Audrey Tang
+
+Some parts copyright 2006 Adam Kennedy
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
